@@ -12,6 +12,8 @@
 
 #include <QTextEdit>
 
+#include "processui_export.h"
+
 /*
  *    \class KTextEditVT
  *   \brief The KTextEditVT class provides a widget that is used to edit and display
@@ -38,7 +40,7 @@
  *    will insert the text  "Hello" at the current character position.
  *    (Character 08 is the literal backspace character.  Treated as equivalent to character 127)
  */
-class Q_DECL_EXPORT KTextEditVT : public QTextEdit
+class PROCESSUI_EXPORT KTextEditVT : public QTextEdit
 {
     Q_OBJECT
     Q_PROPERTY(bool parseAnsiEscapeCodes READ parseAnsiEscapeCodes WRITE setParseAnsiEscapeCodes)
