@@ -15,6 +15,8 @@
 
 #include <processcore/processes.h>
 
+#include "processui_export.h"
+
 namespace KSysGuard
 {
 class Processes;
@@ -29,16 +31,15 @@ class ProcessModelPrivate;
 // please keep it this way even if you port this library to have a _export.h header file
 #define KSYSGUARD_EXPORT
 #else
-#define KSYSGUARD_EXPORT Q_DECL_EXPORT
+#define KSYSGUARD_EXPORT PROCESSUI_EXPORT
 #endif
 
 class KSYSGUARD_EXPORT ProcessModel : public QAbstractItemModel
 {
     Q_OBJECT
-    Q_ENUMS(Units)
 
 public:
-    /** Storage for history values. PercentageHistoryRole returns a QVector of this. */
+    /** Storage for history values. PercentageHistoryRole returns a QList of this. */
     struct PercentageHistoryEntry {
         unsigned long timestamp; // in ms, origin undefined as only the delta matters
         float value;
@@ -118,7 +119,7 @@ public:
     KSysGuard::Processes *processController() const; // The processes instance
 
     /** Returns the list of extra attributes provided by plugins */
-    const QVector<KSysGuard::ProcessAttribute *> extraAttributes() const;
+    const QList<KSysGuard::ProcessAttribute *> extraAttributes() const;
 
     /** Convenience function to get the number of processes.
      *
@@ -166,6 +167,7 @@ public:
 
     /** When displaying memory sizes, this is the units it should be displayed in */
     enum Units { UnitsAuto, UnitsKB, UnitsMB, UnitsGB, UnitsTB, UnitsPB, UnitsPercentage };
+    Q_ENUM(Units)
     /** Set the units memory sizes etc should be displayed in */
     void setUnits(Units units);
     /** The units memory sizes etc should be displayed in */
@@ -209,7 +211,7 @@ private:
     friend class ProcessModelPrivate;
 };
 
-Q_DECLARE_METATYPE(QVector<ProcessModel::PercentageHistoryEntry>);
+Q_DECLARE_METATYPE(QList<ProcessModel::PercentageHistoryEntry>);
 Q_DECLARE_TYPEINFO(ProcessModel::PercentageHistoryEntry, Q_PRIMITIVE_TYPE);
 
 #endif
