@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2019 David Edmundson <davidedmundson@kde.org>
+    SPDX-FileCopyrightText: 2019 David Edmundson <davidedmundson@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #pragma once
 
@@ -35,8 +22,8 @@ class SensorInfo
 {
 public:
     SensorInfo() = default;
-    QString name;        // Translated name of the sensor.
-    QString shortName;   // Shorter translated name of the sensor, to use when space is constrained.
+    QString name; // Translated name of the sensor.
+    QString shortName; // Shorter translated name of the sensor, to use when space is constrained.
     QString description; // Translated description of the sensor.
     QVariant::Type variantType = QVariant::Invalid;
     KSysGuard::Unit unit = KSysGuard::UnitInvalid; // Both a format hint and implies data type (i.e double/string)
