@@ -132,8 +132,9 @@ void KSignalPlotter::reorderBeams(const QList<int> &newOrder)
 
 void KSignalPlotter::changeRange(qreal min, qreal max)
 {
-    if (min == d->mUserMinValue && max == d->mUserMaxValue)
+    if (min == d->mUserMinValue && max == d->mUserMaxValue) {
         return;
+    }
     d->mUserMinValue = min;
     d->mUserMaxValue = max;
     d->calculateNiceRange();
@@ -141,31 +142,37 @@ void KSignalPlotter::changeRange(qreal min, qreal max)
 
 void KSignalPlotter::removeBeam(int index)
 {
-    if (index >= d->mBeamColors.size())
+    if (index >= d->mBeamColors.size()) {
         return;
-    if (index >= d->mBeamColorsLight.size())
+    }
+    if (index >= d->mBeamColorsLight.size()) {
         return;
+    }
     d->mBeamColors.removeAt(index);
     d->mBeamColorsLight.removeAt(index);
 
     QList<QList<qreal>>::Iterator i;
     for (i = d->mBeamData.begin(); i != d->mBeamData.end(); ++i) {
-        if ((*i).size() >= index)
+        if ((*i).size() >= index) {
             (*i).removeAt(index);
+        }
     }
-    if (d->mUseAutoRange)
+    if (d->mUseAutoRange) {
         d->rescale();
+    }
 }
 
 void KSignalPlotter::setScaleDownBy(qreal value)
 {
-    if (d->mScaleDownBy == value)
+    if (d->mScaleDownBy == value) {
         return;
+    }
     d->mScaleDownBy = value;
     d->mBackgroundImage = QPixmap(); // we changed a paint setting, so reset the cache
     d->calculateNiceRange();
     update();
 }
+
 qreal KSignalPlotter::scaleDownBy() const
 {
     return d->mScaleDownBy;
@@ -185,8 +192,9 @@ bool KSignalPlotter::useAutoRange() const
 
 void KSignalPlotter::setMinimumValue(qreal min)
 {
-    if (min == d->mUserMinValue)
+    if (min == d->mUserMinValue) {
         return;
+    }
     d->mUserMinValue = min;
     d->calculateNiceRange();
     update();
@@ -200,8 +208,9 @@ qreal KSignalPlotter::minimumValue() const
 
 void KSignalPlotter::setMaximumValue(qreal max)
 {
-    if (max == d->mUserMaxValue)
+    if (max == d->mUserMaxValue) {
         return;
+    }
     d->mUserMaxValue = max;
     d->calculateNiceRange();
     update();
@@ -225,8 +234,9 @@ qreal KSignalPlotter::currentMinimumRangeValue() const
 
 void KSignalPlotter::setHorizontalScale(uint scale)
 {
-    if (scale == d->mHorizontalScale || scale == 0)
+    if (scale == d->mHorizontalScale || scale == 0) {
         return;
+    }
 
     d->mHorizontalScale = scale;
     d->updateDataBuffers();
@@ -246,8 +256,9 @@ int KSignalPlotter::horizontalScale() const
 
 void KSignalPlotter::setShowVerticalLines(bool value)
 {
-    if (d->mShowVerticalLines == value)
+    if (d->mShowVerticalLines == value) {
         return;
+    }
     d->mShowVerticalLines = value;
     d->mBackgroundImage = QPixmap(); // we changed a paint setting, so reset the cache
 #ifdef USE_QIMAGE
@@ -265,8 +276,9 @@ bool KSignalPlotter::showVerticalLines() const
 
 void KSignalPlotter::setVerticalLinesDistance(uint distance)
 {
-    if (distance == d->mVerticalLinesDistance)
+    if (distance == d->mVerticalLinesDistance) {
         return;
+    }
     d->mVerticalLinesDistance = distance;
     d->mBackgroundImage = QPixmap(); // we changed a paint setting, so reset the cache
 #ifdef USE_QIMAGE
@@ -284,8 +296,9 @@ uint KSignalPlotter::verticalLinesDistance() const
 
 void KSignalPlotter::setVerticalLinesScroll(bool value)
 {
-    if (value == d->mVerticalLinesScroll)
+    if (value == d->mVerticalLinesScroll) {
         return;
+    }
     d->mVerticalLinesScroll = value;
 #ifdef USE_QIMAGE
     d->mScrollableImage = QImage();
@@ -302,8 +315,9 @@ bool KSignalPlotter::verticalLinesScroll() const
 
 void KSignalPlotter::setShowHorizontalLines(bool value)
 {
-    if (value == d->mShowHorizontalLines)
+    if (value == d->mShowHorizontalLines) {
         return;
+    }
     d->mShowHorizontalLines = value;
 #ifdef USE_QIMAGE
     d->mScrollableImage = QImage();
@@ -321,8 +335,9 @@ bool KSignalPlotter::showHorizontalLines() const
 
 void KSignalPlotter::setShowAxis(bool value)
 {
-    if (value == d->mShowAxis)
+    if (value == d->mShowAxis) {
         return;
+    }
     d->mShowAxis = value;
     d->mBackgroundImage = QPixmap(); // we changed a paint setting, so reset the cache
 #ifdef USE_QIMAGE
@@ -344,16 +359,18 @@ QString KSignalPlotter::svgBackground() const
 }
 void KSignalPlotter::setSvgBackground(const QString &filename)
 {
-    if (d->mSvgFilename == filename)
+    if (d->mSvgFilename == filename) {
         return;
+    }
     d->mSvgFilename = filename;
 #ifdef SVG_SUPPORT
     if (filename.isEmpty()) {
         delete d->mSvgRenderer;
         d->mSvgRenderer = NULL;
     } else {
-        if (!d->mSvgRenderer)
+        if (!d->mSvgRenderer) {
             d->mSvgRenderer = new Plasma::Svg(this);
+        }
         d->mSvgRenderer->setImagePath(d->mSvgFilename);
     }
 #endif
@@ -363,8 +380,9 @@ void KSignalPlotter::setSvgBackground(const QString &filename)
 
 void KSignalPlotter::setMaxAxisTextWidth(int axisTextWidth)
 {
-    if (d->mAxisTextWidth == axisTextWidth)
+    if (d->mAxisTextWidth == axisTextWidth) {
         return;
+    }
     d->mAxisTextWidth = axisTextWidth;
     d->mBackgroundImage = QPixmap(); // we changed a paint setting, so reset the cache
     update();
@@ -390,6 +408,7 @@ void KSignalPlotter::changeEvent(QEvent *event)
         break;
     }
 }
+
 #ifdef GRAPHICS_SIGNAL_PLOTTER
 void KGraphicsSignalPlotter::resizeEvent(QGraphicsSceneResizeEvent *event)
 {
@@ -410,19 +429,22 @@ void KSignalPlotter::resizeEvent(QResizeEvent *event)
             boundingBox.adjust(0, offset, 0, -offset);
 
         int padding = 1;
-        if (boundingBox.width() > d->mAxisTextWidth + 50)
+        if (boundingBox.width() > d->mAxisTextWidth + 50) {
             padding = 10; // If there's plenty of room, at 10 pixels for padding the axis text, so that it looks nice
+        }
 
-        if (layoutDirection() == Qt::RightToLeft)
+        if (layoutDirection() == Qt::RightToLeft) {
             boundingBox.setRight(boundingBox.right() - d->mAxisTextWidth - padding);
-        else
+        } else {
             boundingBox.setLeft(d->mAxisTextWidth + padding);
+        }
         d->mActualAxisTextWidth = d->mAxisTextWidth;
     } else {
         d->mActualAxisTextWidth = 0;
     }
-    if (d->mShowThinFrame)
+    if (d->mShowThinFrame) {
         boundingBox.adjust(0, 0, -1, -1);
+    }
 
     // Remember bounding box to pass to update, so that we only update the plotting area the next time, if that's the only that thing that has changed
     d->mPlottingArea = boundingBox;
@@ -489,26 +511,33 @@ void KSignalPlotterPrivate::recalculateMaxMinValueForSample(const QList<qreal> &
         qreal value = 0;
         for (int i = sampleBuf.count() - 1; i >= 0; i--) {
             qreal newValue = sampleBuf[i];
-            if (!std::isinf(newValue) && !std::isnan(newValue))
+            if (!std::isinf(newValue) && !std::isnan(newValue)) {
                 value += newValue;
+            }
         }
-        if (std::isnan(mMinValue) || mMinValue > value)
+        if (std::isnan(mMinValue) || mMinValue > value) {
             mMinValue = value;
-        if (std::isnan(mMaxValue) || mMaxValue < value)
+        }
+        if (std::isnan(mMaxValue) || mMaxValue < value) {
             mMaxValue = value;
-        if (value > 0.7 * mMaxValue)
+        }
+        if (value > 0.7 * mMaxValue) {
             mRescaleTime = time;
+        }
     } else {
         qreal value;
         for (int i = sampleBuf.count() - 1; i >= 0; i--) {
             value = sampleBuf[i];
             if (!std::isinf(value) && !std::isnan(value)) {
-                if (std::isnan(mMinValue) || mMinValue > value)
+                if (std::isnan(mMinValue) || mMinValue > value) {
                     mMinValue = value;
-                if (std::isnan(mMaxValue) || mMaxValue < value)
+                }
+                if (std::isnan(mMaxValue) || mMaxValue < value) {
                     mMaxValue = value;
-                if (value > 0.7 * mMaxValue)
+                }
+                if (value > 0.7 * mMaxValue) {
                     mRescaleTime = time;
+                }
             }
         }
     }
@@ -531,28 +560,35 @@ void KSignalPlotterPrivate::addSample(const QList<qreal> &sampleBuf)
     }
     mBeamData.prepend(sampleBuf);
     if ((unsigned int)mBeamData.size() > mMaxSamples) {
-        mBeamData.removeLast(); // we have too many.  Remove the last item
-        if ((unsigned int)mBeamData.size() > mMaxSamples)
-            mBeamData
-                .removeLast(); // If we still have too many, then we have resized the widget.  Remove one more.  That way we will slowly resize to the new size
+        // we have too many.  Remove the last item
+        mBeamData.removeLast();
+        if ((unsigned int)mBeamData.size() > mMaxSamples) {
+            // If we still have too many, then we have resized the widget.
+            // Remove one more.  That way we will slowly resize to the new
+            // size
+            mBeamData.removeLast();
+        }
     }
 
     if (mUseAutoRange) {
         recalculateMaxMinValueForSample(sampleBuf, 0);
 
-        if (mRescaleTime++ > mMaxSamples)
+        if (mRescaleTime++ > mMaxSamples) {
             rescale();
-        else if (mMinValue < mNiceMinValue || mMaxValue > mNiceMaxValue
-                 || (mMaxValue > mUserMaxValue && mNiceRange != 1 && mMaxValue < (mNiceRange * 0.75 + mNiceMinValue)) || mNiceRange == 0)
+        } else if (mMinValue < mNiceMinValue || mMaxValue > mNiceMaxValue
+                   || (mMaxValue > mUserMaxValue && mNiceRange != 1 && mMaxValue < (mNiceRange * 0.75 + mNiceMinValue)) || mNiceRange == 0) {
             calculateNiceRange();
+        }
     } else {
         if (mMinValue < mNiceMinValue || mMaxValue > mNiceMaxValue
-            || (mMaxValue > mUserMaxValue && mNiceRange != 1 && mMaxValue < (mNiceRange * 0.75 + mNiceMinValue)) || mNiceRange == 0)
+            || (mMaxValue > mUserMaxValue && mNiceRange != 1 && mMaxValue < (mNiceRange * 0.75 + mNiceMinValue)) || mNiceRange == 0) {
             calculateNiceRange();
+        }
     }
 
-    if (mScrollableImage.isNull())
+    if (mScrollableImage.isNull()) {
         return;
+    }
     QPainter pCache(&mScrollableImage);
     drawBeamToScrollableImage(&pCache, 0);
 }
@@ -597,10 +633,12 @@ void KSignalPlotterPrivate::updateDataBuffers()
      *     1) no wasted space and
      *     2) no loss of precision when drawing the first data point.
      */
-    if (q->isVisible())
+    if (q->isVisible()) {
         mMaxSamples = uint(q->size().width() / mHorizontalScale + 4);
-    else // If it's not visible, we can't rely on sensible values for width.  Store some minimum number of data points
+    } else {
+        // If it's not visible, we can't rely on sensible values for width.  Store some minimum number of data points
         mMaxSamples = qMin((uint)(q->size().width() / mHorizontalScale + 4), NUM_SAMPLES_WHEN_INVISIBLE);
+    }
 }
 
 #ifdef GRAPHICS_SIGNAL_PLOTTER
@@ -610,8 +648,9 @@ void KGraphicsSignalPlotter::paint(QPainter *painter, const QStyleOptionGraphics
 #else
 void KSignalPlotter::paintEvent(QPaintEvent *event)
 {
-    if (testAttribute(Qt::WA_PendingResizeEvent))
+    if (testAttribute(Qt::WA_PendingResizeEvent)) {
         return; // lets not do this more than necessary, shall we?
+    }
     QPainter p(this);
     QPainter *painter = &p;
 #endif
@@ -619,8 +658,9 @@ void KSignalPlotter::paintEvent(QPaintEvent *event)
     uint w = size().width();
     uint h = size().height();
     /* Do not do repaints when the widget is not yet setup properly. */
-    if (w <= 2 || h <= 2)
+    if (w <= 2 || h <= 2) {
         return;
+    }
 
 #ifdef GRAPHICS_SIGNAL_PLOTTER
     bool onlyDrawPlotter = option && d->mPlottingArea.contains(option->exposedRect.toRect());
@@ -629,12 +669,14 @@ void KSignalPlotter::paintEvent(QPaintEvent *event)
 #endif
 
 #ifdef USE_SEPERATE_WIDGET
-    if (onlyDrawPlotter)
+    if (onlyDrawPlotter) {
         return; // The painting will be handled entirely by GraphWidget::paintEvent
+    }
 #endif
 
-    if (!onlyDrawPlotter && d->mShowThinFrame)
+    if (!onlyDrawPlotter && d->mShowThinFrame) {
         d->drawThinFrame(painter, d->mPlottingArea.adjusted(0, 0, 1, 1)); // We have a 'frame' in the bottom and right - so subtract them from the view
+    }
 
 #ifndef USE_SEPERATE_WIDGET
     d->drawWidget(painter, d->mPlottingArea); // Draw the widget only if we don't have a GraphWidget to draw it for us
@@ -651,17 +693,20 @@ void KSignalPlotter::paintEvent(QPaintEvent *event)
         }
     }
 }
+
 #ifdef USE_SEPERATE_WIDGET
 void GraphWidget::paintEvent(QPaintEvent *)
 {
-    if (testAttribute(Qt::WA_PendingResizeEvent))
+    if (testAttribute(Qt::WA_PendingResizeEvent)) {
         return; // lets not do this more than necessary, shall we?
+    }
 
     uint w = width();
     uint h = height();
     /* Do not do repaints when the widget is not yet setup properly. */
-    if (w <= 2 || h <= 2)
+    if (w <= 2 || h <= 2) {
         return;
+    }
     QPainter p(this);
 
     signalPlotterPrivate->drawWidget(&p, QRect(0, 0, w, h));
@@ -675,6 +720,7 @@ void GraphWidget::paintEvent(QPaintEvent *)
     }
 }
 #endif
+
 void KSignalPlotterPrivate::drawWidget(QPainter *p, const QRect &boundingBox)
 {
 #ifdef SVG_SUPPORT
@@ -687,8 +733,9 @@ void KSignalPlotterPrivate::drawWidget(QPainter *p, const QRect &boundingBox)
     }
 #endif
 
-    if (mScrollableImage.isNull())
+    if (mScrollableImage.isNull()) {
         redrawScrollableImage();
+    }
 
     // We draw the pixmap in two halves, wrapping around the window
     if (mScrollOffset > 1) {
@@ -720,24 +767,31 @@ void KSignalPlotterPrivate::drawWidget(QPainter *p, const QRect &boundingBox)
     }
 
     /* Draw scope-like grid vertical lines if it doesn't move.  If it does move, draw it in the dynamic part of the code*/
-    if (mShowVerticalLines && !mVerticalLinesScroll)
+    if (mShowVerticalLines && !mVerticalLinesScroll) {
         drawVerticalLines(p, boundingBox);
+    }
 }
+
 void KSignalPlotterPrivate::drawBackground(QPainter *p, const QRect &boundingBox) const
 {
     p->setRenderHint(QPainter::Antialiasing, false);
 #ifdef SVG_SUPPORT
-    if (!mSvgFilename.isEmpty()) // our background is an svg, so don't paint over the top of it
+    if (!mSvgFilename.isEmpty()) {
+        // our background is an svg, so don't paint over the top of it
         p->fillRect(boundingBox, Qt::transparent);
-    else
+    } else
 #endif
+    {
         p->fillRect(boundingBox, q->palette().brush(QPalette::Base));
+    }
 
-    if (mShowHorizontalLines)
+    if (mShowHorizontalLines) {
         drawHorizontalLines(p, boundingBox.adjusted(0, 0, 1, 0));
+    }
 
-    if (mShowVerticalLines && mVerticalLinesScroll)
+    if (mShowVerticalLines && mVerticalLinesScroll) {
         drawVerticalLines(p, boundingBox, mVerticalLinesOffset);
+    }
 
     p->setRenderHint(QPainter::Antialiasing, true);
 }
@@ -746,10 +800,12 @@ bool KSignalPlotter::thinFrame() const
 {
     return d->mShowThinFrame;
 }
+
 void KSignalPlotter::setThinFrame(bool thinFrame)
 {
-    if (thinFrame == d->mShowThinFrame)
+    if (thinFrame == d->mShowThinFrame) {
         return;
+    }
 
     d->mShowThinFrame = thinFrame;
     update(); // Trigger a repaint
@@ -769,6 +825,7 @@ void KSignalPlotterPrivate::updateSvgBackground(const QRect &boundingBox)
     svgRenderer->paint(&pCache, 0, 0);
 }
 #endif
+
 void KSignalPlotterPrivate::redrawScrollableImage()
 {
     // Align width of bounding box to the size of the horizontal scale
@@ -786,14 +843,16 @@ void KSignalPlotterPrivate::redrawScrollableImage()
     // We need to draw the background for areas without a beam
     int withoutBeamWidth = qMax(mBeamData.size() - 1, 0) * mHorizontalScale;
     QPainter pCache(&mScrollableImage);
-    if (withoutBeamWidth < mScrollableImage.width())
+    if (withoutBeamWidth < mScrollableImage.width()) {
         drawBackground(&pCache, QRect(withoutBeamWidth, 0, alignedWidth - withoutBeamWidth, mScrollableImage.height()));
+    }
 
     /* Draw scope-like grid vertical lines */
     mVerticalLinesOffset = 0;
     if (mBeamData.size() > 2) {
-        for (int i = mBeamData.size() - 2; i >= 0; i--)
+        for (int i = mBeamData.size() - 2; i >= 0; i--) {
             drawBeamToScrollableImage(&pCache, i);
+        }
     }
 }
 
@@ -813,8 +872,10 @@ void KSignalPlotterPrivate::calculateNiceRange()
     qreal max = mUserMaxValue;
     qreal min = mUserMinValue;
     if (mUseAutoRange) {
-        if (!std::isnan(mMaxValue) && mMaxValue * 0.99 > max) // Allow max value to go very slightly over the given max, for rounding reasons
+        // Allow max value to go very slightly over the given max, for rounding reasons
+        if (!std::isnan(mMaxValue) && mMaxValue * 0.99 > max) {
             max = mMaxValue;
+        }
         if (!std::isnan(mMinValue) && mMinValue * 0.99 < min) {
             min = mMinValue;
         }
@@ -822,8 +883,9 @@ void KSignalPlotterPrivate::calculateNiceRange()
 
     /* If the range is too small we will force it to 1.0 since it
      * looks a lot nicer. */
-    if (max - min < 0.000001)
+    if (max - min < 0.000001) {
         max = min + 1;
+    }
 
     qreal range = max - min;
 
@@ -837,32 +899,39 @@ void KSignalPlotterPrivate::calculateNiceRange()
         number_lines_above_zero = int(mHorizontalLinesCount * max / range);
         number_lines_below_zero = mHorizontalLinesCount - number_lines_above_zero - 1; // subtract 1 line for the actual 0 line
         step = qMax(max / (mScaleDownBy * (number_lines_above_zero + 1)), -min / (mScaleDownBy * (number_lines_below_zero + 1)));
-    } else
+    } else {
         step = range / (mScaleDownBy * (mHorizontalLinesCount + 1));
+    }
 
     const int sigFigs = 2; // Number of significant figures of the step to use.  Update the 0.05 below if this changes
     int logdim = (int)floor(log10(step)) - (sigFigs - 1); // find the order of the number, reduced by 1.  E.g. if step=1234 then logdim is 3-1=2
     qreal dim = pow((qreal)10.0, logdim); // e.g.  if step=1234, logdim=2, so dim = 100
     int a = (int)ceil(step / dim - 0.000005); // so a = ceil(1234/100) = ceil(12.34) = 13    (we subtract an epsilon)
 
-    if (logdim >= 0)
-        mPrecision = 0; // Work out the number of decimal places.  e.g. If step=1.5, then logdim = -1 so precision is 1
-    else if (a % 10 == 0) // We just happened to round to a nice number, requiring 1 less precision
+    if (logdim >= 0) {
+        // Work out the number of decimal places.  e.g. If step=1.5, then logdim = -1 so precision is 1
+        mPrecision = 0;
+    } else if (a % 10 == 0) {
+        // We just happened to round to a nice number, requiring 1 less precision
         mPrecision = -logdim - 1;
-    else
+    } else {
         mPrecision = -logdim;
-    step = dim * a; // e.g. if step=1234, dim=100, a=13  so step= 1300.  So 1234 was rounded up to 1300
+    }
+    // e.g. if step=1234, dim=100, a=13  so step= 1300.  So 1234 was rounded up to 1300
+    step = dim * a;
 
     range = mScaleDownBy * step * (mHorizontalLinesCount + 1);
 
     if (alignToXAxis) {
         max = mScaleDownBy * step * (number_lines_above_zero + 1);
         min = -mScaleDownBy * step * (number_lines_below_zero + 1);
-    } else
+    } else {
         max = min + range;
+    }
 
-    if (mNiceMinValue == min && mNiceRange == range)
+    if (mNiceMinValue == min && mNiceRange == range) {
         return; // nothing changed
+    }
 
     mNiceMaxValue = max;
     mNiceMinValue = min;
@@ -880,13 +949,15 @@ void KSignalPlotterPrivate::calculateNiceRange()
 void KSignalPlotterPrivate::drawVerticalLines(QPainter *p, const QRect &boundingBox, int offset) const
 {
     QColor color = q->palette().color(QPalette::Window);
-    if (!mVerticalLinesScroll)
+    if (!mVerticalLinesScroll) {
         color.setAlpha(127);
+    }
     p->setPen(QPen(color, 0));
 
     p->setRenderHint(QPainter::Antialiasing, false);
-    for (int x = boundingBox.right() - (offset % mVerticalLinesDistance); x >= boundingBox.left(); x -= mVerticalLinesDistance)
+    for (int x = boundingBox.right() - (offset % mVerticalLinesDistance); x >= boundingBox.left(); x -= mVerticalLinesDistance) {
         p->drawLine(x, boundingBox.top(), x, boundingBox.bottom());
+    }
     p->setRenderHint(QPainter::Antialiasing, true);
 }
 
@@ -907,19 +978,23 @@ void KSignalPlotterPrivate::drawBeamToScrollableImage(QPainter *p, int index)
 
 void KSignalPlotterPrivate::drawBeam(QPainter *p, const QRect &boundingBox, int horizontalScale, int index)
 {
-    if (mNiceRange == 0)
+    if (mNiceRange == 0) {
         return;
+    }
     QPen pen;
-    if (mHorizontalScale == 1) // Don't use a pen width of 2 if there's only 1 pixel between points
+    if (mHorizontalScale == 1) {
+        // Don't use a pen width of 2 if there's only 1 pixel between points
         pen.setWidth(1);
-    else
+    } else {
         pen.setWidth(2);
+    }
 
     pen.setCapStyle(Qt::FlatCap);
 
     qreal scaleFac = (boundingBox.height() - 2) / mNiceRange;
-    if (mBeamData.size() - 1 <= index)
+    if (mBeamData.size() - 1 <= index) {
         return; // Something went wrong?
+    }
 
     const QList<qreal> &datapoints = mBeamData[index];
     const QList<qreal> &prev_datapoints = mBeamData[index + 1];
@@ -930,11 +1005,12 @@ void KSignalPlotterPrivate::drawBeam(QPainter *p, const QRect &boundingBox, int
     qreal x1 = qMax(boundingBox.right() - horizontalScale, 0);
 
     qreal xaxis = boundingBox.bottom();
-    if (mNiceMinValue < 0)
+    if (mNiceMinValue < 0) {
         xaxis = qMax(qreal(xaxis + mNiceMinValue * scaleFac), qreal(boundingBox.top()));
+    }
 
     const int count = qMin(datapoints.size(), mBeamColors.size());
-    QVector<QPainterPath> paths(count);
+    QList<QPainterPath> paths(count);
     QPointF previous_c0;
     QPointF previous_c1;
     QPointF previous_c2;
@@ -945,24 +1021,27 @@ void KSignalPlotterPrivate::drawBeam(QPainter *p, const QRect &boundingBox, int
     bool firstLine = true;
     for (int j = 0; j < count; ++j) {
         qreal point0 = datapoints[j];
-        if (std::isnan(point0))
+        if (std::isnan(point0)) {
             continue; // Just do not draw points with nans. skip them
+        }
 
         qreal point1 = prev_datapoints[j];
         qreal point2 = prev_prev_datapoints[j];
 
-        if (std::isnan(point1))
+        if (std::isnan(point1)) {
             point1 = point0;
-        else if (mSmoothGraph && !std::isinf(point1)) {
+        } else if (mSmoothGraph && !std::isinf(point1)) {
             // Apply a weighted average just to smooth the graph out a bit
             // Do not try to smooth infinities or nans
             point0 = (2 * point0 + point1) / 3;
-            if (!std::isnan(point2) && !std::isinf(point2))
+            if (!std::isnan(point2) && !std::isinf(point2)) {
                 point1 = (2 * point1 + point2) / 3;
+            }
             // We don't bother to average out y2.  This will introduce slight inaccuracies in the gradients, but they aren't really noticeable.
         }
-        if (std::isnan(point2))
+        if (std::isnan(point2)) {
             point2 = point1;
+        }
 
         if (mStackBeams) {
             point0 = previous_point0 = previous_point0 + point0;
@@ -1004,56 +1083,66 @@ void KSignalPlotterPrivate::drawBeam(QPainter *p, const QRect &boundingBox, int
         firstLine = false;
     }
     for (int j = count - 1; j >= 0; --j) {
-        if (mFillOpacity)
+        if (mFillOpacity) {
             pen.setColor(mBeamColorsLight.at(j));
-        else
+        } else {
             pen.setColor(mBeamColors.at(j));
+        }
         p->strokePath(paths.at(j), pen);
     }
 }
+
 void KSignalPlotterPrivate::drawAxisText(QPainter *p, const QRect &boundingBox)
 {
-    if (mHorizontalLinesCount < 0)
+    if (mHorizontalLinesCount < 0) {
         return;
+    }
     p->setFont(q->font());
     qreal stepsize = mNiceRange / (mScaleDownBy * (mHorizontalLinesCount + 1));
-    if (mActualAxisTextWidth == 0) // If we are drawing completely inside the plotter area, using the Text color
+    if (mActualAxisTextWidth == 0) {
+        // If we are drawing completely inside the plotter area, using the Text color
         p->setPen(QPen(q->palette().brush(QPalette::Text), 0));
-    else
+    } else {
         p->setPen(QPen(q->palette().brush(QPalette::WindowText), 0));
+    }
     int axisTitleIndex = 1;
     QString val;
     int numItems = mHorizontalLinesCount + 2;
     int fontHeight = p->fontMetrics().height();
-    if (numItems == 2 && boundingBox.height() < fontHeight * 2)
+    if (numItems == 2 && boundingBox.height() < fontHeight * 2) {
         numItems = 1;
+    }
     mAxisTextOverlapsPlotter = false;
     for (int y = 0; y < numItems; y++, axisTitleIndex++) {
-        int y_coord =
-            boundingBox.top() + (y * (boundingBox.height() - fontHeight)) / (mHorizontalLinesCount + 1); // Make sure it's y*h first to avoid rounding bugs
+        // Make sure it's y*h first to avoid rounding bugs
+        int y_coord = boundingBox.top() + (y * (boundingBox.height() - fontHeight)) / (mHorizontalLinesCount + 1);
         qreal value;
-        if (y == mHorizontalLinesCount + 1)
+        if (y == mHorizontalLinesCount + 1) {
             value = mNiceMinValue / mScaleDownBy; // sometimes using the formulas gives us a value very slightly off
-        else
+        } else {
             value = mNiceMaxValue / mScaleDownBy - y * stepsize;
+        }
 
         val = scaledValueAsString(value, mPrecision);
         QRect textBoundingRect = p->fontMetrics().boundingRect(val);
 
-        if (textBoundingRect.width() > mActualAxisTextWidth)
+        if (textBoundingRect.width() > mActualAxisTextWidth) {
             mAxisTextOverlapsPlotter = true;
+        }
         int offset = qMax(mActualAxisTextWidth - textBoundingRect.right(), -textBoundingRect.left());
-        if (q->layoutDirection() == Qt::RightToLeft)
+        if (q->layoutDirection() == Qt::RightToLeft) {
             p->drawText(boundingBox.left(), y_coord, boundingBox.width() - offset, fontHeight + 1, Qt::AlignLeft | Qt::AlignTop, val);
-        else
+        } else {
             p->drawText(boundingBox.left() + offset, y_coord, boundingBox.width() - offset, fontHeight + 1, Qt::AlignLeft | Qt::AlignTop, val);
+        }
     }
 }
 
 void KSignalPlotterPrivate::drawHorizontalLines(QPainter *p, const QRect &boundingBox) const
 {
-    if (mHorizontalLinesCount <= 0)
+    if (mHorizontalLinesCount <= 0) {
         return;
+    }
     p->setPen(QPen(q->palette().color(QPalette::Window)));
     for (int y = 0; y <= mHorizontalLinesCount + 1; y++) {
         // note that the y_coord starts from 0.  so we draw from pixel number 0 to h-1.  Thus the -1 in the y_coord
@@ -1069,42 +1158,51 @@ int KSignalPlotter::currentAxisPrecision() const
 
 qreal KSignalPlotter::lastValue(int i) const
 {
-    if (d->mBeamData.isEmpty() || d->mBeamData.first().size() <= i)
+    if (d->mBeamData.isEmpty() || d->mBeamData.first().size() <= i) {
         return std::numeric_limits<qreal>::quiet_NaN();
+    }
     return d->mBeamData.first().at(i);
 }
+
 QString KSignalPlotter::lastValueAsString(int i, int precision) const
 {
-    if (d->mBeamData.isEmpty() || d->mBeamData.first().size() <= i || std::isnan(d->mBeamData.first().at(i)))
+    if (d->mBeamData.isEmpty() || d->mBeamData.first().size() <= i || std::isnan(d->mBeamData.first().at(i))) {
         return QString();
+    }
     return valueAsString(d->mBeamData.first().at(i), precision); // retrieve the newest value for this beam
 }
+
 QString KSignalPlotter::valueAsString(qreal value, int precision) const
 {
-    if (std::isnan(value))
+    if (std::isnan(value)) {
         return QString();
+    }
     value = value / d->mScaleDownBy; // scale the value.  E.g. from Bytes to KiB
     return d->scaledValueAsString(value, precision);
 }
+
 QString KSignalPlotterPrivate::scaledValueAsString(qreal value, int precision) const
 {
     qreal absvalue = qAbs(value);
     if (precision == -1) {
-        if (absvalue >= 99.5)
+        if (absvalue >= 99.5) {
             precision = 0;
-        else if (absvalue >= 0.995 || (mScaleDownBy == 1 && mNiceMaxValue > 20))
+        } else if (absvalue >= 0.995 || (mScaleDownBy == 1 && mNiceMaxValue > 20)) {
             precision = 1;
-        else
+        } else {
             precision = 2;
+        }
     }
 
     if (absvalue < 1E6) {
-        if (precision == 0)
+        if (precision == 0) {
             return mUnit.subs((long)value).toString();
-        else
+        } else {
             return mUnit.subs(value, 0, 'f', precision).toString();
-    } else
+        }
+    } else {
         return mUnit.subs(value, 0, 'g', precision).toString();
+    }
 }
 
 bool KSignalPlotter::smoothGraph() const
@@ -1126,6 +1224,7 @@ bool KSignalPlotter::stackGraph() const
 {
     return d->mStackBeams;
 }
+
 void KSignalPlotter::setStackGraph(bool stack)
 {
     d->mStackBeams = stack;
@@ -1140,6 +1239,7 @@ int KSignalPlotter::fillOpacity() const
 {
     return d->mFillOpacity;
 }
+
 void KSignalPlotter::setFillOpacity(int fill)
 {
     d->mFillOpacity = fill;
@@ -1159,8 +1259,9 @@ QPainterPath KGraphicsSignalPlotter::opaqueArea() const
 QSizeF KGraphicsSignalPlotter::sizeHint(Qt::SizeHint which, const QSizeF &constraint) const
 {
     Q_UNUSED(constraint);
-    if (which == Qt::PreferredSize)
+    if (which == Qt::PreferredSize) {
         return QSizeF(200, 200);
+    }
     return QGraphicsWidget::sizeHint(which, constraint);
 }
 #else
